#wikipedia module contains several functions
import wikipedia
import pyttsx3
import speech_recognition as sr



#giving command to engine
engine=pyttsx3.init('sapi5')
voices=engine.getProperty('voices')
#speak function
def speak(audio):
        engine.setProperty('rate', 150)
        engine.say(audio)
        engine.runAndWait()
#take command :takes user audio as input
def text(query):
        """Search wikipedia by user text input
        """
        results=wikipedia.summary(query,sentences=3)#you can get more than 3 sentences in result
        print(results)
def voice():
        """VOICE search wikipedia
        """
        r=sr.Recognizer()
        r.energy_threshold=3000
        with sr.Microphone() as source:
                print("listening....")
                r.pause_threshold=1
                audio=r.listen(source)
                try:
                        text=r.recognize_google(audio,language='en-IN')
                        print("user said:",text)
                        results=wikipedia.summary(text,sentences=3)#you can get more than 3 sentences in result
                        print(results)
                        speak(results)
                except:
                        speak("try again")        





#This module sends mail using your speech 
#User words are directly send as message
from tuesday import speech
# speech module includes speak function
#getpass module hides the given input
#maintains privacy
from getpass import getpass
import speech_recognition as sr
#simple mail transfer protocol 
import smtplib


def send():
    """Email is send by user VOICE
    """
    try:
        speech.speak("enter your email address!")
        b=input("mail id:")
        speech.speak("password sir")
        a=getpass("password:")
        #SMTP function from smtplib 
        server = smtplib.SMTP('smtp.gmail.com',587)#587 is port number
        server.ehlo()
        server.starttls()
        server.login(b, a)
        speech.speak("to whom sir")
        to = input("mail id:")
        #message to be sent is taken as input
        r=sr.Recognizer()
        r.energy_threshold=5000
        with sr.Microphone() as source:
            speech.speak("What should I say?")
            print("listening...")

            audio=r.listen(source) 
            print("recognizing...") 
            s=r.recognize_google(audio,language='en-IN')
            print(s)
        server.sendmail(b, to, s)
        speech.speak("email sent")
        #necessory to close
        server.close()    
    except Exception as e:
        print(e)
        speech.speak("email not sent")


"""Easy way to store data
"""
import speech_recognition as sr
from tuesday import speech


def create():
        """CREATE a file by your VOICE"""
        speech.speak("name the file ")
        r=sr.Recognizer()
        r.energy_threshold=3000
        with sr.Microphone() as source:
                print("listening....")
                r.pause_threshold=1
                audio=r.listen(source)
                try:  
                        s=r.recognize_google(audio,language='en-IN')
                        print(s)
                        text=s+".txt"

                        f=open(text,"x")
                        f.close()

                        f=open(text,"a")
                
                                       
                
                
                        with sr.Microphone() as source:
                                speech.speak("speak the content")
                                print("listening....")
                                r.pause_threshold=1
                                audio=r.listen(source)
                                print("recognising...")
                                
                                p=r.recognize_google(audio,language='en-IN')
                                print("user said:",p)
                                f.write(p)
                                f.close()
                except:
                        speech.speak("can't recognize")        
def edit():
        """EDIT a file data 
        """
        speech.speak("name of the file")
        r=sr.Recognizer()
        r.energy_threshold=3000
        with sr.Microphone() as source:
                print("listening....")
                r.pause_threshold=1
                audio=r.listen(source)
                try:
                        s=r.recognize_google(audio,language='en-IN')
                        text=s+".txt"
                        f=open(text,"a")
                        
                        with sr.Microphone() as source:
                                speech.speak("say")
                                print("listening....")
                                r.pause_threshold=1
                                
                                audio=r.listen(source)
                                print("recognising...")
                        
                                p=r.recognize_google(audio,language='en-IN')
                                print("user said:",p)
                                f.write(p)
                                f.close()
                except:
                        speech.speak("can't recognize")        
        speech.speak("press ENTER to close")
        input('Press ENTER to exit')             
def access():
        """ACCESS data stored in the file
        """
        speech.speak("name of the file")
        r=sr.Recognizer()
        r.energy_threshold=3000
        with sr.Microphone() as source:
                print("listening....")
                r.pause_threshold=1
                audio=r.listen(source)
                try:
                        s=r.recognize_google(audio,language="en-IN")
                        print(s)
                        text=s+".txt"
                        f=open(text,"r")
                        t=f.readlines()
                        speech.speak(t)    
                        print(t)     
                        f.close()
                        speech.speak("press ENTER to close")
                        input('Press ENTER to exit')
                except:
                        speech.speak("can't recognize")        
         


"""SPEECH module enables your system to speak and listen to your commands very easily
"""
import pyttsx3
import speech_recognition as sr


#giving command to engine
engine=pyttsx3.init('sapi5')
voices=engine.getProperty('voices')
#selecting voice type
engine.setProperty('voice',voices[1].id)
#speak function
def speak(audio):
    """converts string to audio
    """
    
    engine.setProperty('rate', 150)
    engine.say(audio)
    engine.runAndWait()
#take command :takes user audio as input

def takecommand():
    
    r=sr.Recognizer()
    r.energy_threshold=5000
    with sr.Microphone() as source:
        print("listening....")
        r.pause_threshold=1
        audio=r.listen(source)
    try:
        print('recognizing...')
        #language can be manually selected in language variable below
        text=r.recognize_google(audio,language="en-IN")
        print("user said:",text)
    except Exception as e:
        print("can't recognize")
        return "none"
    return text    
def intro():
    
    
    r=sr.Recognizer()
    r.energy_threshold=3000
    with sr.Microphone() as source:
        speak("what is your name")
        
        
        
        print("listening....")
        r.pause_threshold=1
        audio=r.listen(source)
        print('recognizing...')
        try:
            text=r.recognize_google(audio,language="en-IN")
            
            print("user said:",text)
            query=text.replace("my name is","")
            print(query)
            speak(f"hello!{query}, how are you?")
        except:
            speak("can't recognize")    




#This module tells current date and time with high accuracy
#output is in voice form
import datetime
from tuesday import speech
import pyttsx3

#Tells time
def time():
    #Format of time is set
    strtime=datetime.datetime.now().strftime("%H:%M:%S")   
    
    speech.speak(f"the time is {strtime}")
    print(strtime) 
#Tells date    
def date():
    date_object = datetime.date.today()
    speech.speak(f"today's date is {date_object}") 
    print(date_object)   
    


"""Localweather tells the current weather and location with high accuracy
"""

from tuesday import speech
# speech module includes speak function
#imports request module
import requests
#It recognise your speech
import speech_recognition as sr
import geocoder

def weather():
    """Tells current weather
    """    
    api_address='http://api.openweathermap.org/data/2.5/weather?appid=0c42f7f6b53b244c78a418f4f181282a&q='
    speech.speak("name of place sir?")
    r=sr.Recognizer()
    r.energy_threshold=5000
    with sr.Microphone() as source:
        audio=r.listen(source)
        try:
                s=r.recognize_google(audio,language='en-IN')
                print(s)
                speech.speak("processing")
                #using api id geocoder access the weather information
                api_address='http://api.openweathermap.org/data/2.5/weather?appid=0c42f7f6b53b244c78a418f4f181282a&q='
                url = api_address + s
                json_data = requests.get(url).json()
                data=json_data["weather"][0]["description"]
                speech.speak(data)
        except:
                speech.speak("try again")        
def location():#geocoder uses ip address to locate your current location
        """Tells current location
        """
        speech.speak("processing")
        g = geocoder.ip('me')
        a=g.latlng
        b=g.city
        c=g.country
        print(a)
        speech.speak(f"coordinates are {a}")
        print(b)
        speech.speak(f"city is {b}")
        print(c)
        speech.speak(f"and the country is {c}")
        


"""This module enables automatic logins to sites without your interaction
"""


from tuesday import speech
import time
import speech_recognition as sr
from selenium import webdriver
from selenium.webdriver.common.keys import Keys
from getpass import getpass


def facebooknum():
        """login facebook by number
        """
        speech.speak("say your number!")
                
        #user voice is taken as input       
        r=sr.Recognizer()
        r.energy_threshold=3000
        with sr.Microphone() as source:
                audio=r.listen(source)
                try:
                        n=r.recognize_google(audio,language='en-IN')
                        print(n)
                        speech.speak("type your password")
                        b=getpass("your password:")
                        speech.speak("processing your request") 
                        time.sleep(2)
                        driver=webdriver.Chrome()
                        driver.get("https://www.facebook.com/")
                        time.sleep(2)
                        yourphone=driver.find_element_by_xpath("//*[@id='email']")
                        yourphone.send_keys(n)
                        time.sleep(2)
                        pswd=driver.find_element_by_xpath("//*[@id='pass']")
                                
                                
                        pswd.send_keys(b)
                        time.sleep(4)
                        login=driver.find_element_by_xpath("//*[@id='u_0_a']")
                        login.click()
                        login=driver.find_element_by_xpath("//*[@id='u_0_2']")
                        login.click()
                        speech.speak("press ENTER to close")
                        input('Press ENTER to exit')
                except:
                        speech.speak("unable to process your request")               
def facebookemail():
        """login facebook by email
        """
        speech.speak("write your mail id")
        a=input("mail id:")
        speech.speak("write your password")
        b=getpass("password:")
        speech.speak("processing your request") 
        driver=webdriver.Chrome()
        driver.get("https://www.facebook.com/")
        time.sleep(2)
        yourphone=driver.find_element_by_xpath("//*[@id='email']")
        yourphone.send_keys(a)
        time.sleep(2)
        pswd=driver.find_element_by_xpath("//*[@id='pass']")
                        
                        
        pswd.send_keys(b)
        time.sleep(3)
        
        login=driver.find_element_by_xpath("//*[@id='u_0_a']")
        login.click()
        login=driver.find_element_by_xpath("//*[@id='u_0_2']")
        login.click()

        speech.speak("press ENTER to close")
        input('Press ENTER to exit')
                        
def gmail():
        """login gmail very easily
        """
        speech.speak("enter your email address!")
        a=input("mail id:")
        speech.speak("password")
        b=getpass("password:")
        speech.speak("processing your request")     
        driver=webdriver.Chrome()
        driver.get("https://accounts.google.com/signin/v2/identifier?service=mail&flowName=GlifWebSignIn&flowEntry=ServiceLogin")
        time.sleep(2)
        email=driver.find_element_by_xpath("//*[@id='identifierId']")
        email.send_keys(a)
        n=driver.find_element_by_xpath("//*[@id='identifierNext']")
        n.click()
        time.sleep(2)
                        
        passw=driver.find_element_by_xpath("//*[@id='password']/div[1]/div/div[1]/input")
        passw.send_keys(b)
        time.sleep(2)
        m=driver.find_element_by_xpath("//*[@id='passwordNext']")
        m.click()
        speech.speak("press ENTER to close")
        input('Press ENTER to exit')                


#selenium is a webtool which has different functions to control webbrowser
import webbrowser
from tuesday import speech
import speech_recognition as sr
from selenium import webdriver
from selenium.webdriver.common.keys import Keys
import time


def google():
    """VOICE SEARCH ON GOOGLE
    """
    speech.speak("what do you want to search?")
    r=sr.Recognizer()
    r.energy_threshold=5000
    with sr.Microphone() as source:
        audio=r.listen(source)
        try:
            text=r.recognize_google(audio,language='en-IN')
            speech.speak("processing")
            url='https://www.google.com/search?q='
            search=url+text
            webbrowser.open(search)
        except:
            speech.speak("can't recognize")
def youtubeplay():
    """PLAY video using your voice
    """
    speech.speak("what do you want to play?")
    r=sr.Recognizer()
    r.energy_threshold=5000
    with sr.Microphone() as source:
        audio=r.listen(source)
        try:
                text=r.recognize_google(audio,language='en-IN')
                speech.speak("processing")
                driver=webdriver.Chrome()
                url="https://www.youtube.com/results?search_query="
                search=url+text
                driver.get(search)
                time.sleep(1)
                play=driver.find_element_by_xpath("//*[@id='video-title']")
                play.click()
                speech.speak("press ENTER to close")
                input('Press ENTER to exit')
        except:
                speech.speak("unable to process your request")         
def youtubesearch():
    speech.speak("what do you want to search?")
    r=sr.Recognizer()
    r.energy_threshold=5000
    with sr.Microphone() as source:
        audio=r.listen(source)
        try:
                text=r.recognize_google(audio,language='en-IN')
                speech.speak("processing")
                driver=webdriver.Chrome()
                url="https://www.youtube.com/results?search_query="
                search=url+text
                driver.get(search)
                speech.speak("press ENTER to close")
                input('Press ENTER to exit') 
        except:
                speech.speak("can't recognize")        

   

        




"""Controls SHUTDOWN , RESTART  of system and open file or execute file 
"""
import os
import speech_recognition as sr
from tuesday import speech


def shutdown():
    """Shutdown the system
    """
    speech.speak("goodnight sir!")
    os.system("shutdown /s /t 1")
def restart():
    """Restart the system
    """
    speech.speak("restarting sir")
    os.system("shutdown /r /t 1")  
def openfile(path):
    """Open file according to given path
    """
    os.startfile(path)    



#Voice controlled search
#Only DOMAIN SUFFIX is required
from tuesday import speech
#Webbrowser module provides accessibility to browser
import webbrowser
import speech_recognition as sr
import pyttsx3

def Open(SUFFIX):
    '''input is .com,.net,.in .....etc'''
    try:
        r=sr.Recognizer()
        r.energy_threshold=5000
        with sr.Microphone() as source:
            speech.speak("name of the site")
            audio=r.listen(source)
            print('recognizing...')
            text=r.recognize_google(audio,language='en-IN')
            print("user said:",text)
        search=text+SUFFIX
        #Open required site     
        webbrowser.open(search)
    except:
        speech.speak("try again")    



from .File import create
from .File import edit
from .File import access
from .localweather import location
from .localweather import weather
from .search import google
from .search import youtubeplay
from .search import youtubesearch
from .searchwiki import text
from .searchwiki import voice
from .sendmail import send
from .social import gmail
from .social import facebookemail
from .social import facebooknum
from .speech import speak
from .speech import takecommand
from .speech import intro
from .system import shutdown
from .system import restart
from .system import openfile
from .websites import Open
from .whatisthetime import date
from .whatisthetime import time





import setuptools
from setuptools import setup

def readme():
    with open('README.md') as f:
        README=f.read()
    return README    

setuptools.setup(
    name="tuesday",
    version="3.0.0",
    author="OSD999",
    author_email="osdev99@gmail.com",
    description="A python package for automation",
    long_description=readme() ,
    long_description_content_type="text/markdown",
    url="https://github.com/om9999/Tuesday",
    
    python_requires='>=3',
    install_requires=['selenium','wikipedia','pyttsx3','speechRecognition','requests','PyAudio','geocoder',],
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    
   
)